@@ -17,6 +17,7 @@ import os
 
 from keystoneclient.openstack.common.apiclient import exceptions as ks_exc
 
+from solumclient.builder import client as builder_client
 from solumclient import client as solum_client
 from solumclient.common import exc
 from solumclient.openstack.common.apiclient import exceptions
@@ -75,7 +76,7 @@ class CommandsBase(object):
 
         client_args = parsed.__dict__
 
-        if not (parsed.os_auth_token and parsed.solum_url):
+        if not parsed.os_auth_token:
             # Remove arguments that are not to be passed to the client in this
             # case.
             del client_args['os_auth_token']
@@ -100,12 +101,12 @@ class CommandsBase(object):
                                        "either --os-auth-url or via "
                                        "env[OS_AUTH_URL]")
 
+        if client_args['action'] == 'build':
+            self.client = builder_client.get_client(parsed.solum_api_version,
+                                                    **client_args)
         else:
-            client_args['endpoint'] = client_args['solum_url']
-
-        del client_args['solum_url']
-        self.client = solum_client.get_client(parsed.solum_api_version,
-                                              **client_args)
+            self.client = solum_client.get_client(parsed.solum_api_version,
+                                                  **client_args)
 
         if action in self._actions:
             try:
@@ -124,7 +125,7 @@ class CommandsBase(object):
 
     @property
     def _actions(self):
-        """Action handler"""
+        """Action handler."""
         return dict((attr, getattr(self, attr))
                     for attr in dir(self)
                     if not attr.startswith('_')
