@@ -24,6 +24,8 @@ import six
 from stevedore import extension
 from testtools import matchers
 
+from solumclient.builder.v1 import image
+from solumclient.common import yamlutils
 from solumclient.openstack.common.apiclient import auth
 from solumclient.openstack.common import cliutils
 from solumclient import solum
@@ -39,16 +41,6 @@ FAKE_ENV = {'OS_USERNAME': 'username',
             'OS_TENANT_NAME': 'tenant_name',
             'OS_AUTH_URL': 'http://no.where'}
 
-plan_file_data = (
-    'name: ex1\n'
-    'description: Nodejs express.\n'
-    'artifacts:\n'
-    '- name: nodeus\n'
-    '  artifact_type: application.heroku\n'
-    '  content:\n'
-    '    href: https://github.com/paulczar/example-nodejs-express.git\n'
-    '  language_pack: auto')
-
 languagepack_file_data = (
     '{"language-pack-type":"Java", "language-pack-name":"Java version 1.4."}')
 
@@ -269,8 +261,9 @@ class TestSolum(base.TestCase):
 
         mock_app_create.return_value = FakeResource('foo', 'foo', 'foo', 'foo')
         expected_printed_dict_args = mock_app_create.return_value._asdict()
-        plan_data = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
-        mopen = mock.mock_open(read_data=plan_data)
+        raw_data = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
+        plan_data = yamlutils.dump(yamlutils.load(raw_data))
+        mopen = mock.mock_open(read_data=raw_data)
         with mock.patch('%s.open' % solum.__name__, mopen, create=True):
             self.make_env()
             self.shell("app create /dev/null")
@@ -279,6 +272,33 @@ class TestSolum(base.TestCase):
                 expected_printed_dict_args,
                 wrap=72)
 
+    @mock.patch.object(cliutils, "print_dict")
+    @mock.patch.object(solum.AppCommands, "_show_public_keys")
+    @mock.patch.object(plan.PlanManager, "create")
+    def test_app_create_with_private_github_repo(self, mock_app_create,
+                                                 mock_show_pub_keys,
+                                                 mock_print_dict):
+        FakeResource = collections.namedtuple(
+            "FakeResource", "uuid name description uri artifacts")
+
+        mock_app_create.return_value = FakeResource('foo', 'foo', 'foo', 'foo',
+                                                    'artifacts')
+        expected_printed_dict_args = mock_app_create.return_value._asdict()
+        expected_printed_dict_args.pop('artifacts')
+        expected_show_pub_keys_args = 'artifacts'
+        raw_data = 'version: 1\nname: ex_plan1\ndescription: dsc1.'
+        plan_data = yamlutils.dump(yamlutils.load(raw_data))
+        mopen = mock.mock_open(read_data=raw_data)
+        with mock.patch('%s.open' % solum.__name__, mopen, create=True):
+            self.make_env()
+            self.shell("app create /dev/null")
+            mock_app_create.assert_called_once_with(plan_data)
+            mock_print_dict.assert_called_once_with(
+                expected_printed_dict_args,
+                wrap=72)
+            mock_show_pub_keys.assert_called_once_with(
+                expected_show_pub_keys_args)
+
     @mock.patch.object(plan.PlanManager, "list")
     def test_app_list(self, mock_app_list):
         self.make_env()
@@ -301,6 +321,22 @@ class TestSolum(base.TestCase):
         self.shell("app show %s" % the_id)
         mock_app_find.assert_called_once_with(name_or_id=the_id)
 
+    @mock.patch.object(solum.AppCommands, "_show_public_keys")
+    @mock.patch.object(plan.PlanManager, "find")
+    def test_app_get_private_github_repo(self, mock_app_find,
+                                         mock_show_pub_keys):
+        self.make_env()
+        the_id = str(uuid.uuid4())
+        FakeResource = collections.namedtuple(
+            "FakeResource", "uuid name description uri artifacts")
+        mock_app_find.return_value = FakeResource('foo', 'foo', 'foo', 'foo',
+                                                  'artifacts')
+        expected_show_pub_keys_args = 'artifacts'
+        self.shell("app show %s" % the_id)
+        mock_app_find.assert_called_once_with(name_or_id=the_id)
+        mock_show_pub_keys.assert_called_once_with(
+            expected_show_pub_keys_args)
+
     # LanguagePack Tests #
     @mock.patch.object(languagepack.LanguagePackManager, "list")
     def test_languagepack_list(self, mock_lp_list):
@@ -328,6 +364,23 @@ class TestSolum(base.TestCase):
                 expected_printed_dict_args,
                 wrap=72)
 
+    @mock.patch.object(image.ImageManager, "create")
+    def test_languagepack_build(self, mock_image_build):
+        FakeResource = collections.namedtuple("FakeResource",
+                                              "uuid name description "
+                                              "compiler_versions os_platform")
+        mock_image_build.return_value = FakeResource(
+            'foo', 'foo', 'foo', 'foo', 'foo')
+        lp_metadata = '{"OS": "Ubuntu"}'
+        mopen = mock.mock_open(read_data=lp_metadata)
+        with mock.patch('%s.open' % solum.__name__, mopen, create=True):
+            self.make_env()
+            self.shell("languagepack build lp_name github.com/test /dev/null")
+            mock_image_build.assert_called_once_with(
+                name='lp_name',
+                source_uri='github.com/test',
+                lp_metadata=lp_metadata)
+
     @mock.patch.object(languagepack.LanguagePackManager, "delete")
     def test_languagepack_delete(self, mock_lp_delete):
         self.make_env()
