@@ -15,6 +15,8 @@
 import six
 
 from solumclient.common import base as solum_base
+from solumclient.common import exc
+from solumclient.common import yamlutils
 from solumclient.openstack.common.apiclient import base as apiclient_base
 from solumclient.openstack.common import uuidutils
 
@@ -81,11 +83,43 @@ class PlanManager(solum_base.CrudManager, solum_base.FindMixin):
     key = 'plan'
 
     def list(self, **kwargs):
-        return super(PlanManager, self).list(base_url="/v1", **kwargs)
+        kwargs = self._filter_kwargs(kwargs)
+        kwargs.setdefault("headers", kwargs.get("headers", {}))
+        kwargs['headers']['Content-Type'] = 'x-application/yaml'
+        resp = self.client.get(
+            self.build_url(base_url="/v1", **kwargs), **kwargs)
+        try:
+            resp_plan = yamlutils.load(resp.content)
+        except ValueError as e:
+            raise exc.BaseException(message='Could not load Plan. '
+                                            'Reason: %s' % e.message)
+        return [Plan(self, res, loaded=True) for res in resp_plan if res]
 
-    def create(self, **kwargs):
-        return super(PlanManager,
-                     self).create(base_url="/v1", **kwargs)
+    def create(self, plan, **kwargs):
+        kwargs = self._filter_kwargs(kwargs)
+        kwargs['data'] = plan
+        kwargs.setdefault("headers", kwargs.get("headers", {}))
+        kwargs['headers']['Content-Type'] = 'x-application/yaml'
+        resp = self.client.post(
+            self.build_url(base_url="/v1", **kwargs), **kwargs)
+        try:
+            resp_plan = yamlutils.load(resp.content)
+        except ValueError as e:
+            raise exc.BaseException(message='Could not load Plan. '
+                                            'Reason: %s' % e.message)
+        return Plan(self, resp_plan)
+
+    def _get(self, url, response_key=None):
+        kwargs = {'headers': {}}
+        kwargs['headers']['Content-Type'] = 'x-application/yaml'
+        resp = self.client.get(url, **kwargs)
+        try:
+            resp_plan = yamlutils.load(resp.content)
+        except ValueError as e:
+            raise exc.BaseException(message='Could not load Plan. '
+                                            'Reason: %s' % e.message)
+
+        return Plan(self, resp_plan, loaded=True)
 
     def get(self, **kwargs):
         return super(PlanManager, self).get(base_url="/v1", **kwargs)
@@ -101,9 +135,19 @@ class PlanManager(solum_base.CrudManager, solum_base.FindMixin):
             else:
                 return super(PlanManager, self).findone(name=name_or_uuid)
 
-    def update(self, **kwargs):
-        return super(PlanManager,
-                     self).update(base_url="/v1", **kwargs)
+    def update(self, plan, **kwargs):
+        kwargs = self._filter_kwargs(kwargs)
+        kwargs['data'] = plan
+        kwargs.setdefault("headers", kwargs.get("headers", {}))
+        kwargs['headers']['Content-Type'] = 'x-application/yaml'
+        resp = self.client.put(self.build_url(base_url="/v1", **kwargs),
+                               **kwargs)
+        try:
+            resp_plan = yamlutils.load(resp.content)
+        except ValueError as e:
+            raise exc.BaseException(message='Could not load Plan. '
+                                            'Reason: %s' % e.message)
+        return self.resource_class(self, resp_plan)
 
     def delete(self, **kwargs):
         return super(PlanManager, self).delete(base_url="/v1", **kwargs)
